@@ -1,17 +1,16 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.008-6-g8d4d708
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.009-5-g5e9cdca
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::Git::Contributors::VERSION = '0.009';
+our $VERSION = '0.010';
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
 use List::Util 1.33 'none';
 use Git::Wrapper 0.035;
 use Try::Tiny;
-use Safe::Isa;
 use Path::Tiny;
 use Data::Dumper;
 use Moose::Util::TypeConstraints 'enum';
@@ -39,7 +38,7 @@ has order_by => (
 has paths => (
     isa => 'ArrayRef[Str]',
     lazy => 1,
-    default => sub { [] },
+    default => sub { [ shift->zilla->root . '' ] },
     traits => ['Array'],
     handles => { paths => 'elements' },
 );
@@ -49,11 +48,13 @@ around dump_config => sub
     my ($orig, $self) = @_;
     my $config = $self->$orig;
 
+    my @paths = $self->paths;
+
     $config->{+__PACKAGE__} = {
         include_authors => $self->include_authors,
         include_releaser  => $self->include_releaser,
         order_by => $self->order_by,
-        paths => [ $self->paths ],
+        paths => [ @paths == 1 ? () : @paths ],
     };
 
     return $config;
@@ -79,14 +80,13 @@ sub _contributors
         $in_repo = $self->_git(RUN => 'status');
     }
     catch {
-        $self->log($_->$_isa('Git::Wrapper::Exception') ? $_->error : $_) ;
+        $self->log(
+            blessed($_) && $_->isa('Git::Wrapper::Exception') ? $_->error : $_
+        );
     };
 
     return [] if not $in_repo;
 
-    my @paths = $self->paths;
-    unshift @paths, '--' if @paths;
-
     my @data = try {
         $self->_git(shortlog =>
             {
@@ -94,7 +94,7 @@ sub _contributors
                 summary => 1,
                 $self->order_by eq 'commits' ? ( numbered => 1 ) : (),
             },
-            'HEAD', @paths,
+            'HEAD', '--', $self->paths,
         );
     };
 
@@ -107,10 +107,10 @@ sub _contributors
 
     if (not $self->include_authors)
     {
-        my $authors = $self->zilla->authors;
+        my @author_emails = map { /(<[^>]+>)/g } @{ $self->zilla->authors };
         @contributors = grep {
             my $contributor = $_;
-            none { $contributor eq $_ } @$authors;
+            none { $contributor =~ /$_/ } @author_emails;
         } @contributors;
     }
 
@@ -176,7 +176,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -305,4 +305,10 @@ This software is copyright (c) 2014 by Karen Etheridge.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Kent Fredric
+
+Kent Fredric <kentnl@cpan.org>
+
 =cut
